#!/usr/local/bin/perl -w
# scripts/deploydb.pl

use strict;
use warnings;

use Data::Dumper;

use Schema;

my $dbconnections = {
    mysql   => [ "dbi:mysql:unittest;host=somehost;port=someport", 'someuser', 'somepass' ],
    sqlite  => [ 'dbi:SQLite:db/test.db' ],
    oracle  => [ 'dbi:Oracle:SOMETABLESPACE', 'unittest', 'somepass', { quote_char => q{"}, name_sep => q{.} } ],
};

my $action = $ARGV[0]||'';
if ( $action =~ m/^(\-)+h/ ) {
    usage();
}
elsif ( $action eq 'create' ) {
    my $dbtype = $ARGV[1] || '';
    my $drop = $ARGV[2] || '';
    $dbtype =~ m{ mysql | sqlite | oracle }xms
        || usage();
    $dbconnections->{$dbtype}
        || die "unknown database type: $dbtype";

    my $schema = Schema->connect( @{ $dbconnections->{$dbtype} } )
        || die "could not connect to db: ".Dumper($dbconnections->{$dbtype});

    my $args = {};
    if ( $drop ) {
        print "dropping tables\n";
        $args->{ add_drop_table } = 1;
    }

    $schema->deploy($args);

    print "deployed to $dbtype\n";
}
else { # generate SQL DDL files
    my $args = {
        quote_table_names => 1,
        quote_field_names => 1,
        add_drop_table => 1,
    };

    my $schema = Schema->connect( @{ $dbconnections->{'sqlite'} } )
        || die "could not connect to db: ".Dumper($dbconnections->{'sqlite'});

    my $preversion = undef;

    $schema->create_ddl_dir( ['Oracle','MySQL','SQLite','PostgreSQL'], $schema->VERSION, 'sql', $preversion, $args );

    print 'wrote SQL DDL to sql sub-directory for schema version '.$schema->VERSION."\n";
}

sub usage {
    print "usage:\n",
        "$0 [-h | --help]\n",
        "       this help\n",
        "$0 create [mysql|sqlite|oracle] [drop]\n",
        "       create tables in database\n",
        "$0\n",
        "       create sql/Schema-*.sql DDL files\n";
    exit(0);
 }