#!/usr/local/bin/perl -w
# scripts/testpopulate.pl

use strict;
use warnings;

use Data::Dumper;

use Schema;

my $dbconnections = {
    mysql   => [ "dbi:mysql:unittest;host=somehost;port=someport", 'someuser', 'somepass' ],
    sqlite  => [ 'dbi:SQLite:db/test.db' ],
    oracle  => [ 'dbi:Oracle:SOMETABLESPACE', 'unittest', 'somepass', { quote_char => q{"}, name_sep => q{.} } ],
};

my $dbtype = $ARGV[0]||'';
$dbtype =~ m{ mysql | sqlite | oracle }xms
    || die "usage: $0 [mysql|sqlite|oracle] [-d]\ndatabase type - mysql or sqlite or oracle";

$dbconnections->{$dbtype}
    || die "unknown database type: $dbtype";

my $schema = Schema->connect( @{ $dbconnections->{$dbtype} } )
    || die "could not connect to db: ".Dumper($dbconnections->{$dbtype});

populate($schema);

print "populated $dbtype\n";

sub populate {
    my $schema = shift || die;

    $schema->txn_begin;

    $schema->resultset($_)->delete  # has to be in right order to avoid constraint violations
        for qw( User );

    my @keys;
    $schema->populate('User', [
        [qw( login fullname )],
        [ 'im.a_guest'                              => 'A. Guest' ],
        [ unittest                                  => 'Ms. Unity Test' ],
    ]);

    @keys = # hmm, Schema/Role.pm doesn't use PK::Auto and yet unless we call in list context it doesn't populate, not sure why
    $schema->populate('Role', [
        [qw( name description )],
        [ webmaster                     => 'Webmasters have full permissions' ],
        [ guest                         => 'Guests have minimal permissions' ],
    ]);

    @keys = $schema->populate('UserRoles', [
        [qw( user_login role_name )],
        [ 'im.a_guest'                          => 'guest' ],
        [ unittest                              => 'webmaster' ],
    ]);

    $schema->txn_commit;
}
